Features
********


This section describes all features that are shipped with this package.


Scenario Features
=================

.. autoclass:: balderhub.battery.lib.scenario_features.BatteryLevelReader
    :members:

.. autoclass:: balderhub.battery.lib.scenario_features.BatterySimFeature
    :members:

.. autoclass:: balderhub.battery.lib.scenario_features.BatteryTestCriteriaConfig
    :members:

.. autoclass:: balderhub.battery.lib.scenario_features.DeviceActivityFeature
    :members:

.. autoclass:: balderhub.battery.lib.scenario_features.IsPoweredOn
    :members:

.. autoclass:: balderhub.battery.lib.scenario_features.RemovableBatterySimFeature
    :members:

Setup Features
==============

.. autoclass:: balderhub.battery.lib.setup_features.BatterySimWithProgrammableDcPowerSupply
    :members:
